import { Change, Changed, Enabled, EntityFilter, Info, InstantRange, Organized } from '@yukawa/chain-base-angular-domain';
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.Account <br/>
*/
export interface Account {
    credentials?: Credentials;
    details?: {
        [key: string]: Object;
    };
    passChangeDate?: string;
    roleContexts?: RoleContext[];
    /**
    *	@deprecated
    */
    roles?: string[];
    status?: AccountStatus;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.AccountEntity <br/>
*/
export interface AccountEntity extends Account {
    readonly getCredentials?: Credentials;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.AccountStatus <br/>
*/
export interface AccountStatus extends Enabled {
    accountNonExpired?: boolean;
    accountNonLocked?: boolean;
    credentialsNonExpired?: boolean;
    enabled?: boolean;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.Credentials <br/>
*/
export interface Credentials extends Organized {
    /**
    *	@example yuk
    */
    orgId?: string;
    /**
    *	@example admin
    */
    password?: string;
    /**
    *	@example eyJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJhZG1pbiIsImlhdCI6MTU4NTM4MDcwMCwiZXhwIjoxNzM5MTcyNzAwLCJzY29wZSI6WyJST0xFX1VTRVIiLCJST0xFX0lORk8iLCJST0xFX0FETUlOIl0sImRldGFpbHMiOnsic2FtcGxlSWQiOiI0NzExIn19.sibnG_8ZFfW3oJ0qKyET40k8C5vDtTt7lcGXjc6fkPA
    */
    token?: string;
    /**
    *	@example GOOGLE
    */
    tokenProvider?: string;
    /**
    *	@example admin
    */
    username?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.GroupContext <br/>
*/
export interface GroupContext {
    groups?: string[];
    orgId?: string;
    /**
    *	@example aaaa1111
    */
    userId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.Revocation <br/>
*/
export interface Revocation extends Changed {
    change?: Change;
    cutOff?: string;
    refreshTokenId?: string;
    refreshTokenValidity?: string;
    revocationId?: number;
    type?: RevocationType;
    username?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.RevocationFilter <br/>
*/
export interface RevocationFilter extends EntityFilter {
    cutOffRange?: InstantRange;
    orAny?: RevocationFilter[];
    refreshTokenId?: string;
    refreshTokenValidityRange?: InstantRange;
    revocationId?: number;
    type?: RevocationType;
    username?: string;
}
export declare enum RevocationType {
    GLOBAL_CUT_OFF = "GLOBAL_CUT_OFF",
    USER_CUT_OFF = "USER_CUT_OFF",
    USER_SINGLE = "USER_SINGLE"
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.RoleContext <br/>
*/
export interface RoleContext {
    orgId?: string;
    roles?: string[];
    /**
    *	@example aaaa1111
    */
    userId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.RoleInfo <br/>
*/
export interface RoleInfo extends Info {
    /**
    *	@example main
    */
    scope?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.security.domain.TokenRequest <br/>
*/
export interface TokenRequest {
    orgId?: string;
    roles?: string[];
    /**
    *	@example admin
    */
    username?: string;
}
